==> haskell-src-exts-util-0.2.3-27-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-src-exts-util.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: haskell-src-exts-util
version: 0.2.3
id: haskell-src-exts-util-0.2.3-BmunyOj48FNFulpde9PxJq
key: haskell-src-exts-util-0.2.3-BmunyOj48FNFulpde9PxJq
license: BSD-3-Clause
copyright: All Rights Reserved
maintainer: pepeiborra@gmail.com
author: Neil Mitchell, Jose Iborra
homepage: https://github.com/pepeiborra/haskell-src-exts-util
synopsis: Helper functions for working with haskell-src-exts trees
description:
    Helper functions for working with haskell-src-exts trees.
category: language
abi: fa31539a9cf5c5cb9cd10eddb7b07bc4
exposed: True
exposed-modules:
    Language.Haskell.Exts.Util
hidden-modules: Language.Haskell.Exts.Bracket
                Language.Haskell.Exts.FreeVars Language.Haskell.Exts.Util.Internal
                Paths_haskell_src_exts_util
import-dirs: /usr/lib/ghc-8.6.1/site-local/haskell-src-exts-util-0.2.3
library-dirs: /usr/lib/ghc-8.6.1/site-local/haskell-src-exts-util-0.2.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/haskell-src-exts-util-0.2.3
hs-libraries: HShaskell-src-exts-util-0.2.3-BmunyOj48FNFulpde9PxJq
depends:
    base-4.12.0.0 containers-0.6.0.1
    data-default-0.7.1.1-9TvgjOMl8fiEDpKR9EhMBO
    haskell-src-exts-1.20.3-IkQYKv04XvTHpsRModKyEr transformers-0.5.5.0
    uniplate-1.6.12-Ed4mFedxMBwFsYmdtCWiP0
haddock-interfaces: /usr/share/doc/haskell-src-exts-util/html/haskell-src-exts-util.haddock
haddock-html: /usr/share/doc/haskell-src-exts-util/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-src-exts-util-0.2.3-28-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-src-exts-util.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: haskell-src-exts-util
version: 0.2.3
id: haskell-src-exts-util-0.2.3-HYmMTmfNWLd5ySa205SosF
key: haskell-src-exts-util-0.2.3-HYmMTmfNWLd5ySa205SosF
license: BSD-3-Clause
copyright: All Rights Reserved
maintainer: pepeiborra@gmail.com
author: Neil Mitchell, Jose Iborra
homepage: https://github.com/pepeiborra/haskell-src-exts-util
synopsis: Helper functions for working with haskell-src-exts trees
description:
    Helper functions for working with haskell-src-exts trees.
category: language
abi: eddcbb73e4c41d7ffd45f40194a3c959
exposed: True
exposed-modules:
    Language.Haskell.Exts.Util
hidden-modules: Language.Haskell.Exts.Bracket
                Language.Haskell.Exts.FreeVars Language.Haskell.Exts.Util.Internal
                Paths_haskell_src_exts_util
import-dirs: /usr/lib/ghc-8.6.1/site-local/haskell-src-exts-util-0.2.3
library-dirs: /usr/lib/ghc-8.6.1/site-local/haskell-src-exts-util-0.2.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/haskell-src-exts-util-0.2.3
hs-libraries: HShaskell-src-exts-util-0.2.3-HYmMTmfNWLd5ySa205SosF
depends:
    base-4.12.0.0 containers-0.6.0.1
    data-default-0.7.1.1-9TvgjOMl8fiEDpKR9EhMBO
    haskell-src-exts-1.20.3-A5XUXpbZhj6I91HrOhAKk7 transformers-0.5.5.0
    uniplate-1.6.12-GVHtXpvaVINBWZh60Xk7ZL
haddock-interfaces: /usr/share/doc/haskell-src-exts-util/html/haskell-src-exts-util.haddock
haddock-html: /usr/share/doc/haskell-src-exts-util/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
